module LUSI
  module API
    module Core

      # The root of the LUSI API exception hierarchy
      class APIError < StandardError

        def initialize(message = nil, url: nil)
          super(message || 'LUSI API error')
          @url = url
        end

      end


      # Indicates an error with the LUSI API call (e.g. network error)
      class APICallError < APIError; end


      # Indicates a LUSI API timeout error
      class APITimeoutError < APICallError; end


      # Indicates a successful LUSI API call which returned invalid XML or a document containing an error header
      class APIResponseError < APIError

        def initialize(message = nil, status: nil, fault: nil, error_code: nil, **kwargs)
          super(message, **kwargs)
          @error_code = error_code
          @fault = fault
          @status = status
        end

      end


      # Indicates an invalid response from the LUSI API
      class APIContentError < APIResponseError; end


      # Indicates a LUSI API permission-denied error
      class APIPermissionError < APIResponseError; end


    end
  end
end
